##############
Result Objects
##############

.. currentmodule:: couchbase.result

.. autoclass:: AsyncGetReplicaResult
   :show-inheritance:
   :members:


.. autoclass:: AsyncGetResult
   :show-inheritance:
   :members:


.. autoclass:: AsyncMultiGetResult
   :show-inheritance:
   :members:


.. autoclass:: AsyncMultiMutationResult
   :show-inheritance:
   :members:


.. autoclass:: AsyncMutationResult
   :show-inheritance:
   :members:


.. autoclass:: AsyncResult
   :show-inheritance:
   :members:


.. autoclass:: AsyncWrapper
   :show-inheritance:
   :members:


.. autoclass::ContentProxy
   :show-inheritance:
   :members:


.. autoclass:: ContentProxySubdoc
   :show-inheritance:
   :members:


.. autoclass:: ExistsResult
   :show-inheritance:
   :members:


.. autoclass:: GetReplicaResult
   :show-inheritance:
   :members:


.. autoclass:: GetResult
   :show-inheritance:
   :members:


.. autoclass:: LookupInResult
   :show-inheritance:
   :members:


.. autoclass:: MultiGetResult
   :show-inheritance:
   :members:


.. autoclass:: MultiMutationResult
   :show-inheritance:
   :members:


.. autoclass:: MultiResult
   :show-inheritance:
   :members:

.. autoclass:: MutateInResult
   :show-inheritance:
   :members:


.. autoclass:: MutationResult
   :show-inheritance:
   :members:


.. autoclass:: PingResult
   :show-inheritance:
   :members:

.. autoclass:: PingResult
   :show-inheritance:
   :members:


.. autoclass:: Result
   :show-inheritance:
   :members:


.. autoclass:: ViewMetaData
   :show-inheritance:
   :members:

.. autoclass:: ViewResult
   :show-inheritance:
   :members:

.. autoclass:: ViewRow
   :show-inheritance:
   :members:
